==> endeavour_42.0.orig.tar.xz: Endeavour-v42.0/README.md <==
# Endeavour

Endeavour is an intuitive and powerful application to manage your personal tasks. It uses GNOME
technologies and has complete integration with the GNOME desktop environment.


## Getting Involved

If you want to contribute, please check the [Contributions Guidelines][contribution-guidelines]. If
you want to contribute with code, also check the [Code Style Guidelines][code-style]. It is expected
that contributions follow these guidelines, so it is important to read them **before** submitting
your contribution.

All contributions should follow the GNOME Code of Conduct. You can read more at our
[Contribution Guidelines][contribution-guidelines].

To reduce the overload of the maintainers, full code reviews only happen under the following
conditions:

 * The proposed changes don't break the build.
 * Commit messages strictly follows the [documented style][contribution-guidelines].
 * Code strictly follows [the documented code style][code-style].

Should these conditions aren't met, the contributor will be pointed out and asked to review their
code.


## Getting In Touch

We use IRC as the main form of real-time communication. Asynchronous communication happens on
[Endeavour GitLab Project][gitlab]. You can join us at the [#gnome-todo][irc-channel] room on
[GNOME IRC servers][irc-wiki-page].

All communications should follow the GNOME Code of Conduct. You can read more at our
[Contribution Guidelines][contribution-guidelines]. It is expected from everyone to always be
respectful and kind.

Stop by and say hello!


[code-style]: https://gitlab.gnome.org/World/Endeavour/blob/main/doc/HACKING.md
[contribution-guidelines]: https://gitlab.gnome.org/World/Endeavour/blob/main/doc/CONTRIBUTING.md
[gitlab]: https://gitlab.gnome.org/World/Endeavour
[irc-channel]: irc://irc.gnome.org/gnome-todo
[irc-wiki-page]: https://wiki.gnome.org/Community/GettingInTouch/IRC

==> endeavour_43.0.orig.tar.xz: Endeavour-43.0/README.md <==
# Endeavour

Endeavour is an intuitive and powerful application to manage your personal tasks. It uses GNOME
technologies and has complete integration with the GNOME desktop environment.


## Getting Involved

If you want to contribute, please check the [Contributions Guidelines][contribution-guidelines]. If
you want to contribute with code, also check the [Code Style Guidelines][code-style]. It is expected
that contributions follow these guidelines, so it is important to read them **before** submitting
your contribution.

All contributions should follow the GNOME Code of Conduct. You can read more at our
[Contribution Guidelines][contribution-guidelines].

To reduce the overload of the maintainers, full code reviews only happen under the following
conditions:

 * The proposed changes don't break the build.
 * Commit messages strictly follows the [documented style][contribution-guidelines].
 * Code strictly follows [the documented code style][code-style].

Should these conditions aren't met, the contributor will be pointed out and asked to review their
code.


## Getting In Touch

We use IRC as the main form of real-time communication. Asynchronous communication happens on
[Endeavour GitLab Project][gitlab]. You can join us at the [#endeavour:gnome.org][matrix-channel] room on the
[GNOME Matrix channels][matrix-wiki-page].

All communications should follow the GNOME Code of Conduct. You can read more at our
[Contribution Guidelines][contribution-guidelines]. It is expected from everyone to always be
respectful and kind.

Stop by and say hello!


[code-style]: https://gitlab.gnome.org/World/Endeavour/blob/main/doc/HACKING.md
[contribution-guidelines]: https://gitlab.gnome.org/World/Endeavour/blob/main/doc/CONTRIBUTING.md
[gitlab]: https://gitlab.gnome.org/World/Endeavour
[matrix-channel]: https://matrix.to/#/#endeavour:gnome.org
[matrix-wiki-page]: https://wiki.gnome.org/GettingInTouch/Matrix
